Django XLIFF 0.1 — django-xliff 0.1 documentation

django-xliff 0.1 documentation

# Django XLIFF 0.1

- Table of Contents
- index
  next

# Django XLIFF 0.1

XML Localization Interchange File Format (XLIFF) is an XML-based format created to standardize the way localizable data are passed between tools during localization. OASIS standardized XLIFF in 2002. Django-XLIFF conforms to version 1.2.

XLIFF is a bit more verbose than the Django’s standard XML output. Sample output looks like (extra white space added for readability:

    <?xml version="1.0" encoding="utf-8"?>
    <xliff xmlns="urn:oasis:names:tc:xliff:document:1.2"
           version="1.2"
           xmlns:d="https://docs.djangoproject.com/">
      <file datatype="database"
            source-language="en-us"
            original="simpleapp.tag.2">
        <body>
          <group resname="simpleapp.tag.2" restype="row">
            <trans-unit resname="data"
                        translate="no"
                        id="data"
                        restype="x-SlugField">
              <source>tag2</source>
            </trans-unit>
            <trans-unit d:keytype="pk"
                        d:to="contenttypes.contenttype"
                        restype="x-ForeignKey"
                        d:rel="ManyToOneRel"
                        resname="content_type"
                        translate="no"
                        id="content_type">
              <source>37</source>
            </trans-unit>
            <trans-unit resname="object_id"
                        translate="no"
                        id="object_id"
                        restype="x-PositiveIntegerField">
              <source>200</source>
            </trans-unit>
          </group>
        </body>
      </file>
    </xliff>

## Contents

- Getting Started
  - Installation
  - Exporting and Importing
- Reference
  - Django XML to XLIFF
  - Settings